==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicContourLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicXYTriangulatingSeriesDescription } from "./GeographicXYTriangulatingSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicContourLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicContourLineSeriesDescription, _super);
    function GeographicContourLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.ds = null;
        _this.dn = null;
        _this.dm = null;
        _this.dk = null;
        _this.dr = null;
        return _this;
    }
    GeographicContourLineSeriesDescription.prototype.get_type = function () {
        return "GeographicContourLineSeries";
    };
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "valueMemberPath", {
        get: function () {
            return this.ds;
        },
        set: function (a) {
            this.ds = a;
            this.e("ValueMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "fillScale", {
        get: function () {
            return this.dn;
        },
        set: function (a) {
            this.dn = a;
            this.e("FillScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "actualFillScale", {
        get: function () {
            return this.dm;
        },
        set: function (a) {
            this.dm = a;
            this.e("ActualFillScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "valueResolver", {
        get: function () {
            return this.dk;
        },
        set: function (a) {
            this.dk = a;
            this.e("ValueResolver");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "triangulationStatusChangedRef", {
        get: function () {
            return this.dr;
        },
        set: function (a) {
            this.dr = a;
            this.e("TriangulationStatusChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicContourLineSeriesDescription.$t = markType(GeographicContourLineSeriesDescription, 'GeographicContourLineSeriesDescription', GeographicXYTriangulatingSeriesDescription.$);
    return GeographicContourLineSeriesDescription;
}(GeographicXYTriangulatingSeriesDescription));
export { GeographicContourLineSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/GeographicContourLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicXYTriangulatingSeriesDescription } from "./GeographicXYTriangulatingSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicContourLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicContourLineSeriesDescription, _super);
    function GeographicContourLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.fs = null;
        _this.fo = null;
        _this.fn = null;
        _this.fl = null;
        _this.fr = null;
        return _this;
    }
    GeographicContourLineSeriesDescription.prototype.get_type = function () {
        return "GeographicContourLineSeries";
    };
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "valueMemberPath", {
        get: function () {
            return this.fs;
        },
        set: function (a) {
            this.fs = a;
            this.g("ValueMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "fillScale", {
        get: function () {
            return this.fo;
        },
        set: function (a) {
            this.fo = a;
            this.g("FillScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "actualFillScale", {
        get: function () {
            return this.fn;
        },
        set: function (a) {
            this.fn = a;
            this.g("ActualFillScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "valueResolver", {
        get: function () {
            return this.fl;
        },
        set: function (a) {
            this.fl = a;
            this.g("ValueResolver");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicContourLineSeriesDescription.prototype, "triangulationStatusChangedRef", {
        get: function () {
            return this.fr;
        },
        set: function (a) {
            this.fr = a;
            this.g("TriangulationStatusChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicContourLineSeriesDescription.$t = markType(GeographicContourLineSeriesDescription, 'GeographicContourLineSeriesDescription', GeographicXYTriangulatingSeriesDescription.$);
    return GeographicContourLineSeriesDescription;
}(GeographicXYTriangulatingSeriesDescription));
export { GeographicContourLineSeriesDescription };
